import useSWR from "swr";
import { ApiRespons, fetcher, ikkeRevalidate, FetchStatus } from "./api";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { Point } from "geojson";
import { Dayjs } from "dayjs";
import { tilEnkelTimestampStr } from "../utils/tid";
import { erKontraktGyldig } from "./context/kartdataHelpers";
import { Kontrakt } from "./context/kontraktAtoms";

export interface SisteKjøretøyDto {
    produksjonsdataRestRec: number;
    lokasjon: Point[];
    eksternReferanse?: string;
}

export function useHentSisteKjøretøy(
    kontrakt: Kontrakt | undefined,
    tidspunkt: Dayjs,
): ApiRespons<SisteKjøretøyDto[]> | undefined {
    const { data } = useSWR<ApiRespons<SisteKjøretøyDto[]>>(
        erKontraktGyldig(kontrakt, tidspunkt)
            ? `${GCP_MEDIATOR_URL}/siste-kjøretøy?elrappkontraktid=${
                  kontrakt!.elrappId
              }&tidspunkt=${tilEnkelTimestampStr(tidspunkt)}`
            : null,
        fetcher,
        ikkeRevalidate,
    );
    if (!erKontraktGyldig(kontrakt, tidspunkt)) {
        return {
            suksess: true,
            data: [],
            status: FetchStatus.Suksess,
        };
    }
    return data;
}
