"use client";

import React, { ChangeEvent, useState } from "react";
import {
    Friksjonsmåling,
    FriksjonsmålingMetadata,
    lagFriksjonsmålinger,
    lagFriksjonsmålingMetadata,
} from "./friksjonsmålingTyper";
import dynamic from "next/dynamic";
import { Spinner } from "../components/fellesKomponenter/spinner/Spinner";
import styled from "styled-components";
import { breakpointNettbrett } from "../utils/constants";
import { FriksjonskartProps } from "./Friksjonskart";
import { atom } from "jotai/index";
import { FriksjonsmålingTabell } from "./FriksjonsmålingTabell";
import { SideHeader } from "../components/sideheader/SideHeader";
import { ColumnWrapper, RowWrapper } from "../components/fellesKomponenter/wrappers/wrappers";
import { FriksjonsmLingMetadataPanel } from "./FriksjonsmålingMetadataPanel";
import { KnappSekundær } from "../components/fellesKomponenter/knapper/KnappSekundær";
import { Tekst } from "../components/fellesKomponenter/typografi/Tekst";
import { Friksjonsgraf } from "./Friksjonsgraf";

export const aktivFriksjonsmålingAtom = atom<Friksjonsmåling | undefined>(undefined);

export const FriksjonsdashboardSide = () => {
    const [målinger, setMålinger] = useState<Friksjonsmåling[]>([]);
    const [friksjonsmålingMetadata, setFriksjonsmålingMetadata] =
        useState<FriksjonsmålingMetadata>();
    const [filopplastingsfeil, setFilopplastingsfeil] = useState<string | undefined>();

    const håndterFilopplasting = (event: ChangeEvent<HTMLInputElement>) => {
        setFilopplastingsfeil(undefined);

        if (event.target.files === null) {
            setFilopplastingsfeil("Klarte ikke finne filen");
            return;
        }

        const fil = event.target.files[0];
        const filLeser = new FileReader();

        filLeser.onload = function (event) {
            if (event.target === null) {
                setFilopplastingsfeil("Klarte ikke lese filen");
                return;
            }

            const tekst = event.target.result;
            const lines = tekst!.toString().split("\n");

            const målinger = lagFriksjonsmålinger(lines);
            const målingerMetadata = lagFriksjonsmålingMetadata(lines);

            if (målinger === undefined) {
                setFilopplastingsfeil("Klarte ikke lese filen");
                return;
            }

            setMålinger(målinger);
            setFriksjonsmålingMetadata(målingerMetadata);
        };
        filLeser.readAsText(fil, "ASCII");
    };

    return (
        <div>
            <SideHeader side={"friksjonsdashboard"} />

            <RowWrapper>
                <KartvisningContainer>
                    <DynamicKartvisning friksjonsmålinger={målinger} />
                </KartvisningContainer>
                <Panel>
                    <ColumnWrapper>
                        <KnappSekundær
                            onClick={() => document.getElementById("file")?.click()}
                            size={"Small"}
                        >
                            Last opp friksjonsmåling
                        </KnappSekundær>
                        <input
                            id="file"
                            type="file"
                            onChange={håndterFilopplasting}
                            style={{ display: "none" }}
                        />
                        {filopplastingsfeil && (
                            <StyledTekst noMargin={true}>{filopplastingsfeil}</StyledTekst>
                        )}
                    </ColumnWrapper>
                    <FriksjonsmLingMetadataPanel friksjonsdataMetadata={friksjonsmålingMetadata} />
                </Panel>
            </RowWrapper>
            <Friksjonsgraf friksjonsmålinger={målinger} startDato={friksjonsmålingMetadata?.dato} />
            <FriksjonsmålingTabell startDato={friksjonsmålingMetadata?.dato} />
        </div>
    );
};

const DynamicKartvisning = dynamic<FriksjonskartProps>(
    () => import("./Friksjonskart").then((mod) => mod.Friksjonskart),
    {
        loading: () => <Spinner />,
        ssr: false,
    },
);

const KartvisningContainer = styled.div`
    height: 400px;
    width: 65%;
    @media (max-width: ${breakpointNettbrett}) {
        width: 100%;
    }
`;

const Panel = styled.div`
    width: 35%;
    background-color: var(--gray-light);
    padding: 20px;
    gap: 10px;
    height: 360px;
    overflow: auto;

    @media (max-width: ${breakpointNettbrett}) {
        width: 100%;
    }
`;

const StyledTekst = styled(Tekst)`
    color: var(--red-regular);
    padding-left: 6px;
`;
