import { Friksjonsmåling } from "./friksjonsmålingTyper";
import {
    CartesianGrid,
    Legend,
    Line,
    LineChart,
    ResponsiveContainer,
    Tooltip,
    XAxis,
    YAxis,
} from "recharts";
import dayjs, { Dayjs } from "dayjs";
import { FriksjonsgrafToolip } from "./FriksjonsgrafTooltip";
import { aktivFriksjonsmålingAtom } from "./Friksjonsdashboard";
import { useSetAtom } from "jotai";
import styled from "styled-components";

interface FriksjonsgrafProps {
    friksjonsmålinger: Friksjonsmåling[];
    startDato?: Dayjs;
}

export const Friksjonsgraf = ({ friksjonsmålinger, startDato }: FriksjonsgrafProps) => {
    const setAktivFriksjonsmåling = useSetAtom(aktivFriksjonsmålingAtom);
    const grafdata = friksjonsmålinger;
    return (
        <GrafContainer>
            <ResponsiveContainer width={"90%"} height={360}>
                <LineChart
                    data={grafdata}
                    margin={{
                        top: 5,
                        right: 30,
                        left: 20,
                        bottom: 5,
                    }}
                    onClick={(e) => {
                        e.activePayload && setAktivFriksjonsmåling(e.activePayload[0].payload);
                    }}
                >
                    <CartesianGrid strokeDasharray="3 3" />
                    <XAxis
                        dataKey="tid_ms"
                        type={"number"}
                        tickFormatter={(tick) => formaterXAkse(tick, startDato)}
                    />
                    <YAxis />
                    <Tooltip content={<FriksjonsgrafToolip startDato={startDato} />} />
                    <Legend verticalAlign="top" height={36} />
                    {grafdata && (
                        <Line
                            type="monotone"
                            dataKey="u_V"
                            stroke="#E32129"
                            dot={false}
                            isAnimationActive={false}
                        />
                    )}
                    {grafdata && (
                        <Line
                            type="monotone"
                            dataKey="u_H"
                            stroke="#29E329"
                            dot={false}
                            isAnimationActive={false}
                        />
                    )}
                </LineChart>
            </ResponsiveContainer>
        </GrafContainer>
    );
};

const GrafContainer = styled.div`
    margin-top: 20px;
`;
export const formaterXAkse = (tickItem: string, startDato?: Dayjs) => {
    if (startDato) {
        return dayjs(startDato).add(Number(tickItem), "ms").format("HH:mm");
    }
    return tickItem;
};
