import React from "react";
import { Dayjs } from "dayjs";
import { TooltipProps } from "recharts";
import { NameType, ValueType } from "recharts/types/component/DefaultTooltipContent";
import styled from "styled-components";

interface CustomTooltip extends TooltipProps<ValueType, NameType> {
    startDato?: Dayjs;
}

export const FriksjonsgrafToolip = ({ active, payload, startDato }: CustomTooltip) => {
    const tid_ms = payload && payload[0]?.payload.tid_ms;
    const dato = startDato?.add(tid_ms, "millisecond");

    if (active && payload && payload.length) {
        return (
            <TooltipContainer>
                <p>{`Dato: ${dato && dato.format("DD.MM")}`}</p>
                <p>{`Klokkeslett: ${dato && dato.format("HH:mm")}`}</p>
                <p>{`µ_V: ${payload[0].payload.u_V}`}</p>
                <p>{`µ_H: ${payload[0].payload.u_H}`}</p>
            </TooltipContainer>
        );
    }
    return null;
};

const TooltipContainer = styled.div`
    background-color: white;
    border: 1px solid black;
    padding: 10px;

    p {
        color: var(--gray-dark);
        margin: 0;
    }
`;
