import { GeoJSON, MapContainer, TileLayer } from "react-leaflet";
import React from "react";
import "leaflet/dist/leaflet.css";
import { crsUtm33N } from "../kartSide/utils/crs";
import styles from "../kartSide/Kartvisning/Kartvisning.module.css";
import { Friksjonsmåling } from "./friksjonsmålingTyper";
import {
    finnKartBounds,
    mapFriksjonsmålingerTilKartdata,
    onEachLenkeFeature,
    punktTilLayer,
} from "./friksjonskartUtils";
import { ChangeView } from "../kartSide/Kartvisning/ChangeView";
import { aktivFriksjonsmålingAtom } from "./Friksjonsdashboard";
import { useAtom } from "jotai";

export interface FriksjonskartProps {
    friksjonsmålinger: Friksjonsmåling[];
}

export const Friksjonskart = ({ friksjonsmålinger }: FriksjonskartProps) => {
    const [aktivFriksjonsmåling, setAktivFriksjonsmåling] = useAtom(aktivFriksjonsmålingAtom);
    const kartBounds = finnKartBounds(friksjonsmålinger);

    const handleOnMålingClick = (måling: Friksjonsmåling) => {
        setAktivFriksjonsmåling(måling);
    };

    return (
        <MapContainer
            className={styles.kartvisningokt}
            center={[64.6, 9.5022]}
            scrollWheelZoom
            crs={crsUtm33N}
            zoom={4}
            minZoom={4}
            maxZoom={16}
            zoomControl={false}
            zoomDelta={0.8}
            zoomSnap={0}
            keyboard={false}
            attributionControl={false}
        >
            <TileLayer
                attribution="© NVDB, Geovekst, kommunene og Open Street Map contributors (utenfor Norge)"
                url="https://services.geodataonline.no/arcgis/rest/services/Trafikkportalen/GeocacheTrafikkJPG/MapServer/tile/{z}/{y}/{x}"
                subdomains="123456789"
            />
            <ChangeView kartBounds={kartBounds} medPadding={true} />
            <GeoJSON
                data={mapFriksjonsmålingerTilKartdata(friksjonsmålinger)}
                key={Math.random()}
                onEachFeature={(feature, layer) =>
                    onEachLenkeFeature(feature, layer, handleOnMålingClick, aktivFriksjonsmåling)
                }
                pointToLayer={(feature, latlng) =>
                    punktTilLayer(feature, latlng, aktivFriksjonsmåling?.tid_ms)
                }
            />
        </MapContainer>
    );
};
