import styled from "styled-components";
import { useAtomValue } from "jotai/index";
import { aktivFriksjonsmålingAtom } from "./Friksjonsdashboard";
import { Dayjs } from "dayjs";
import { tilNorskTimestamp } from "../utils/tid";

interface FriksjonsmålingTabellProps {
    startDato?: Dayjs;
}
export const FriksjonsmålingTabell = ({ startDato }: FriksjonsmålingTabellProps) => {
    const friksjonsmåling = useAtomValue(aktivFriksjonsmålingAtom);
    return (
        <StyledTable>
            <thead>
                <StyledTableRow>
                    <StyledTh>Data</StyledTh>
                    <StyledTh>Verdi</StyledTh>
                </StyledTableRow>
            </thead>
            <tbody>
                <StyledTableRow>
                    <StyledTd>Tid</StyledTd>
                    <StyledTd>
                        {friksjonsmåling?.tid_ms &&
                            startDato &&
                            tilNorskTimestamp(startDato.add(friksjonsmåling?.tid_ms, "ms"))}
                    </StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Tid_ms</StyledTd>
                    <StyledTd>{friksjonsmåling?.tid_ms.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>µ_V</StyledTd>
                    <StyledTd>{friksjonsmåling?.u_V.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>µ_H</StyledTd>
                    <StyledTd>{friksjonsmåling?.u_H.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>V_MW_V</StyledTd>
                    <StyledTd>{friksjonsmåling?.v_MW_V.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>V_MW_H</StyledTd>
                    <StyledTd>{friksjonsmåling?.v_MW_H.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>V_TW</StyledTd>
                    <StyledTd>{friksjonsmåling?.v_TW.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Slip_V</StyledTd>
                    <StyledTd>{friksjonsmåling?.slip_V.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Slip_H</StyledTd>
                    <StyledTd>{friksjonsmåling?.slip_H.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>TotalDist</StyledTd>
                    <StyledTd>{friksjonsmåling?.totalDist.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Lat</StyledTd>
                    <StyledTd>{friksjonsmåling?.lat.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Lng</StyledTd>
                    <StyledTd>{friksjonsmåling?.lng.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Veg</StyledTd>
                    <StyledTd>{friksjonsmåling?.veg.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Parsell</StyledTd>
                    <StyledTd>{friksjonsmåling?.parsell.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>MeterVal</StyledTd>
                    <StyledTd>{friksjonsmåling?.meterVal.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Usikker</StyledTd>
                    <StyledTd>{friksjonsmåling?.usikker.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>F_Vertikal_V</StyledTd>
                    <StyledTd>{friksjonsmåling?.f_vertikal_V.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>F_Vertikal_H</StyledTd>
                    <StyledTd>{friksjonsmåling?.f_vertikal_H.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>F_Friksjon_V</StyledTd>
                    <StyledTd>{friksjonsmåling?.f_friksjon_V.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>F_Friksjon_H</StyledTd>
                    <StyledTd>{friksjonsmåling?.f_friksjon_H.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Merke</StyledTd>
                    <StyledTd>{friksjonsmåling?.merke.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>Grenseverdi</StyledTd>
                    <StyledTd>{friksjonsmåling?.grenseverdi.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>OmT</StyledTd>
                    <StyledTd>{friksjonsmåling?.OmT.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>OvT</StyledTd>
                    <StyledTd>{friksjonsmåling?.OvT.toString()}</StyledTd>
                </StyledTableRow>
                <StyledTableRow>
                    <StyledTd>VannT</StyledTd>
                    <StyledTd>{friksjonsmåling?.VannT.toString()}</StyledTd>
                </StyledTableRow>
            </tbody>
        </StyledTable>
    );
};

const StyledTableRow = styled.tr`
    background-color: #f2f2f2;

    &:hover {
        background-color: #ddd;
    }
`;

const StyledTd = styled.td`
    padding: 8px;
    border: 1px solid #ddd;
    text-align: left;
`;

const StyledTh = styled.th`
    padding: 8px;
    border: 1px solid #ddd;
    text-align: left;
    background-color: var(--blue-regular);
    color: white;
`;

const StyledTable = styled.table`
    border-collapse: collapse;
    width: 100%;
`;
