import { Friksjonsmåling } from "./friksjonsmålingTyper";
import { Feature, FeatureCollection } from "geojson";
import * as L from "leaflet";
import { LatLngBoundsExpression, Layer, LeafletMouseEvent } from "leaflet";
import { finnKartBoundsForKooridnater } from "../kartSide/Kartvisning/kartBoundsUtils";

const aktivMålepunktRadius = 10;
const målepunktRadius = 2;

export const mapFriksjonsmålingerTilKartdata = (målinger: Friksjonsmåling[]): FeatureCollection => {
    return {
        type: "FeatureCollection",
        features: målinger.reduce((features: Feature[], måling) => {
            if (måling.tid_ms !== 0) {
                const feature = friksjonsmålingTilFeature(måling);
                features.push(feature);
            }
            return features;
        }, []),
    };
};

const friksjonsmålingTilFeature = (måling: Friksjonsmåling): Feature => {
    return {
        type: "Feature",
        properties: {
            måling: måling,
        },
        geometry: {
            type: "Point",
            coordinates: [måling.lng, måling.lat],
        },
        id: måling.tid_ms.toString(),
    };
};
export const punktTilLayer = (feature: Feature, latlng: L.LatLng, aktivMålepunktTid?: number) => {
    const måling = feature.properties!.måling as Friksjonsmåling;
    return L.circleMarker(latlng, {
        radius: måling.tid_ms === aktivMålepunktTid ? aktivMålepunktRadius : målepunktRadius,
        color: friksjonTilFargekode(måling.u_H, måling.u_V),
        fillColor: friksjonTilFargekode(måling.u_H, måling.u_V),
        fillOpacity: 1,
    });
};

const friksjonTilFargekode = (friksjonH: number, friksjonV: number) => {
    const friksjon = Math.min(friksjonH, friksjonV);
    //TODO Sett fornuftige grenser
    if (friksjon < 0.18) {
        return "#E32129";
    } else if (friksjon < 0.25) {
        return "#E3A729";
    } else if (friksjon < 0.4) {
        return "#E3E329";
    } else {
        return "#29E329";
    }
};

export const onEachLenkeFeature = (
    feature: Feature | undefined,
    layer: Layer,
    handleOnClick: (friksjonsmåling: Friksjonsmåling) => void,
    aktivFriksjonsmåling: Friksjonsmåling | undefined,
) => {
    const onClick = (e: LeafletMouseEvent) => {
        handleOnClick(e.target.feature.properties.måling);
        e.target.setStyle({ radius: aktivMålepunktRadius });
    };
    const onHover = (e: LeafletMouseEvent) => {
        e.target.setStyle({ radius: aktivMålepunktRadius });
    };
    const onOut = (e: LeafletMouseEvent) => {
        const friksjonsmåling = e.target.feature.properties.måling as Friksjonsmåling;
        if (friksjonsmåling.tid_ms === aktivFriksjonsmåling?.tid_ms) {
            e.target.setStyle({ radius: aktivMålepunktRadius });
        } else {
            e.target.setStyle({ radius: målepunktRadius });
        }
    };
    layer.on({
        click: onClick,
        mouseover: onHover,
        mouseout: onOut,
    });
};

export const finnKartBounds = (målinger: Friksjonsmåling[]): LatLngBoundsExpression => {
    const defaultBounds: LatLngBoundsExpression = [
        [69, 12],
        [60, 10],
    ];
    const koordinater = målinger.map((måling) => [måling.lng, måling.lat]);
    return finnKartBoundsForKooridnater(koordinater) ?? defaultBounds;
};
