import dayjs, { Dayjs } from "dayjs";

export type Friksjonsmåling = {
    tid_ms: number;
    u_V: number;
    u_H: number;
    v_MW_V: number; //kmt
    v_MW_H: number; //kmt
    v_TW: number; //kmt
    slip_V: number;
    slip_H: number;
    totalDist: number;
    lat: number;
    lng: number;
    veg: string;
    parsell: number;
    meterVal: boolean;
    usikker: number;
    f_vertikal_V: number;
    f_vertikal_H: number;
    f_friksjon_V: number;
    f_friksjon_H: number;
    merke: number;
    grenseverdi: number;
    OmT: number;
    OvT: number;
    VannT: number;
};

export type FriksjonsmålingMetadata = {
    dato: Dayjs;
    viaFriction: string;
    enheter: number;
    filnavn: string;
    programvareversjon: string;
    sted: string;
    opratør: string;
    vær: string;
    målingskommentarer: string;
    mwKalibreringV: string;
    mwKalibreringH: string;
    twKalibrering: string;
    kalibreringV: { A: number; B: number; C: number };
    kalibreringH: { A: number; B: number; C: number };
    vannfilm: number;
    spor: string;
    utstyr: string;
    utstyrsmerknader: string;
    bilnummer: string;
    vegnettserverversjon: string;
    vegnettsversjon: string;
    fylke: string;
    vei: string;
    retning: string;
    fil: number;
    startHp: string;
    start: number;
    type: string;
    slipp: number;
    overvåkingsgrense: number;
    formål: string;
    stoppHp: string;
    stopp: number;
    utkjørtDistanse: number;
};

export const lagFriksjonsmålingMetadata = (rawMetadata: string[]): FriksjonsmålingMetadata => {
    //TODO: Robustgjør når vi har flere filer
    return {
        dato: lagFriksjonsmålingMetadataDatoFelt(rawMetadata[0]),
        viaFriction: lagFriksjonsmålingMetadataStringFelt(rawMetadata[1]),
        enheter: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[2]),
        filnavn: lagFriksjonsmålingMetadataStringFelt(rawMetadata[4]),
        programvareversjon: lagFriksjonsmålingMetadataStringFelt(rawMetadata[5]),
        sted: lagFriksjonsmålingMetadataStringFelt(rawMetadata[6]),
        opratør: lagFriksjonsmålingMetadataStringFelt(rawMetadata[7]),
        vær: lagFriksjonsmålingMetadataStringFelt(rawMetadata[8]),
        målingskommentarer: lagFriksjonsmålingMetadataStringFelt(rawMetadata[9]),
        mwKalibreringV: lagFriksjonsmålingMetadataStringFelt(rawMetadata[10]),
        mwKalibreringH: lagFriksjonsmålingMetadataStringFelt(rawMetadata[11]),
        twKalibrering: lagFriksjonsmålingMetadataStringFelt(rawMetadata[12]),
        kalibreringV: lagFriksjonsmålingMetadataKalibreringFelt(rawMetadata[13]),
        kalibreringH: lagFriksjonsmålingMetadataKalibreringFelt(rawMetadata[14]),
        vannfilm: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[15]),
        spor: lagFriksjonsmålingMetadataStringFelt(rawMetadata[16]),
        utstyr: lagFriksjonsmålingMetadataStringFelt(rawMetadata[17]),
        utstyrsmerknader: lagFriksjonsmålingMetadataStringFelt(rawMetadata[18]),
        bilnummer: lagFriksjonsmålingMetadataStringFelt(rawMetadata[19]),
        vegnettserverversjon: lagFriksjonsmålingMetadataStringFelt(rawMetadata[20]),
        vegnettsversjon: lagFriksjonsmålingMetadataStringFelt(rawMetadata[21]),
        fylke: lagFriksjonsmålingMetadataStringFelt(rawMetadata[23]),
        vei: lagFriksjonsmålingMetadataStringFelt(rawMetadata[24]),
        retning: lagFriksjonsmålingMetadataStringFelt(rawMetadata[25]),
        fil: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[26]),
        startHp: lagFriksjonsmålingMetadataStringFelt(rawMetadata[27]),
        start: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[28]),
        type: lagFriksjonsmålingMetadataStringFelt(rawMetadata[29]),
        slipp: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[30]),
        overvåkingsgrense: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[31]),
        formål: lagFriksjonsmålingMetadataStringFelt(rawMetadata[32]),
        stoppHp: lagFriksjonsmålingMetadataStringFelt(rawMetadata[34]),
        stopp: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[35]),
        utkjørtDistanse: lagFriksjonsmålingMetadataNumberFelt(rawMetadata[36]),
    };
};

const lagFriksjonsmålingMetadataStringFelt = (rawMetadata: string): string => {
    const metadata = rawMetadata.split(":");
    return metadata[1].replace("\r", "");
};

const lagFriksjonsmålingMetadataDatoFelt = (rawMetadata: string): Dayjs => {
    const metadata = rawMetadata.split(":");
    return dayjs((metadata[1] + ":" + metadata[2]).replace("\r", ""));
};

const lagFriksjonsmålingMetadataNumberFelt = (rawMetadata: string): number => {
    const metadata = rawMetadata.split(":");
    return Number(metadata[1].replace("\r", ""));
};
const lagFriksjonsmålingMetadataKalibreringFelt = (
    rawMetadata: string,
): { A: number; B: number; C: number } => {
    const metadata = rawMetadata.split(":");
    return {
        A: Number(metadata[2].split(",")[0]),
        B: Number(metadata[3].split(",")[0]),
        C: Number(metadata[4].replace("\r", "")),
    };
};
export const lagFriksjonsmåling = (rawMåling: string): Friksjonsmåling => {
    //TODO: Robustgjør når vi har flere filer
    const måling = rawMåling.split("\t");
    return {
        tid_ms: Number(måling[0]),
        u_V: Number(måling[1]),
        u_H: Number(måling[2]),
        v_MW_V: Number(måling[3]),
        v_MW_H: Number(måling[4]),
        v_TW: Number(måling[5]),
        slip_H: Number(måling[6]),
        slip_V: Number(måling[7]),
        totalDist: Number(måling[8]),
        lat: Number(måling[9]),
        lng: Number(måling[10]),
        veg: måling[11] + måling[12],
        parsell: Number(måling[13]),
        meterVal: måling[14] === "true",
        usikker: Number(måling[15]),
        f_vertikal_V: Number(måling[16]),
        f_vertikal_H: Number(måling[17]),
        f_friksjon_V: Number(måling[18]),
        f_friksjon_H: Number(måling[19]),
        merke: Number(måling[20]),
        grenseverdi: Number(måling[21]),
        OmT: Number(måling[22]),
        OvT: Number(måling[23]),
        VannT: Number(måling[24]),
    };
};

export const lagFriksjonsmålinger = (rawMålinger: string[]): Friksjonsmåling[] | undefined => {
    const målingStartLinje = finnMålingStartLinje(rawMålinger);
    if (målingStartLinje === undefined) {
        return undefined;
    }
    return rawMålinger.slice(målingStartLinje + 1).map((måling) => lagFriksjonsmåling(måling)); // +1 for å hoppe over sammenlikningsString
};

const finnMålingStartLinje = (lines: string[]): number | undefined => {
    const sammenlikningsString = "Tid [ms]";
    const målingerStartIndeks = lines.findIndex((måling, index) => {
        return måling.includes(sammenlikningsString);
    });
    return målingerStartIndeks === -1 ? undefined : målingerStartIndeks;
};
