import React from "react";
import styled from "styled-components";
import { hentUnikeGrafdata } from "./grafUtils";
import { Grafdata } from "./Grafer";
import { KnappUtenStyling } from "../../components/fellesKomponenter/knapper/KnappUtenStyling";
import {
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
    GrafvalgLoggEvent,
} from "../../utils/loggFrontend";

export const CustomLegend = ({
    grafdata,
    setGrafdata,
}: {
    grafdata: Grafdata[];
    setGrafdata: (data: Grafdata[]) => void;
}) => {
    const unikeGrafdata = hentUnikeGrafdata(grafdata);

    const toggleProduksjonstype = (tittel: string) => {
        const newGrafdata: Grafdata[] = grafdata.map((_grafdata) => {
            if (_grafdata.tittel === tittel) {
                return {
                    ..._grafdata,
                    visible: !_grafdata.visible,
                };
            } else {
                return { ..._grafdata };
            }
        });
        setGrafdata(newGrafdata);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.grafvalg,
            GrafvalgLoggEvent.produksjonsfilter,
            tittel,
        );
    };

    return (
        <LegendContainer>
            {Array.isArray(unikeGrafdata) &&
                unikeGrafdata?.map((e, index) => (
                    <KnappUtenStyling
                        onClick={() => toggleProduksjonstype(e.tittel)}
                        key={`item-${index}`}
                    >
                        <LegendItem color={e.color} visible={e.visible}>
                            {e.tittel}
                        </LegendItem>
                    </KnappUtenStyling>
                ))}
        </LegendContainer>
    );
};

const LegendContainer = styled.span`
    display: flex;
    flex-direction: row;
    background-color: white;
    margin: 10px 10px -40px 10px;
    justify-content: center;
    position: relative;
    z-index: 6000;
`;

const LegendItem = styled.p<{ color: string; visible: boolean }>`
    display: flex;
    margin: 0 10px;
    color: ${(props) => (props.visible ? props.color : `var(--gray-regular-dark)`)};

    &:before {
        content: "";
        height: 18px;
        width: 18px;
        margin-bottom: 15px;
        border: 1px solid black;
        background-color: ${(props) => (props.visible ? props.color : "white")};
        margin-right: 10px;
    }
`;
