import { atom } from "jotai/index";
import { Grafdata } from "../grafer/Grafer";

export enum DoseringsType {
    dosering = "dosering",
    sprederbredde = "sprederbredde",
}

export enum HastighetsType {
    hastighetKmHAvg = "hastighetKmHAvg",
}

export enum GrafType {
    hastighet = "hastighet",
    dosering = "dosering",
}
export const aktivHoverRecordAtom = atom<number[] | undefined>(undefined);

const aktivGraf = atom<GrafType>(GrafType.hastighet);
export const aktivGrafAtom = atom<GrafType, [GrafType], void>(
    (get) => get(aktivGraf),
    (get, set, update: GrafType) => {
        set(aktivGraf, update);
        set(
            dataKeyAtom,
            update === GrafType.hastighet ? HastighetsType.hastighetKmHAvg : DoseringsType.dosering,
        );
    },
);

const doseringsType = atom<DoseringsType>(DoseringsType.dosering);
export const doseringsTypeAtom = atom<DoseringsType, [DoseringsType], void>(
    (get) => get(doseringsType),
    (get, set, update: DoseringsType) => {
        set(doseringsType, update);
        set(dataKeyAtom, update);
    },
);

const dataKey = atom<HastighetsType | DoseringsType>(HastighetsType.hastighetKmHAvg);

export const dataKeyAtom = atom<
    HastighetsType | DoseringsType,
    [HastighetsType | DoseringsType],
    void
>(
    (get) => get(dataKey),
    (get, set, update: HastighetsType | DoseringsType) => {
        set(dataKey, update);
        set(reflinjeIKartAtom, undefined);
    },
);
export const grafdataAtom = atom<Grafdata[]>([]);
export const grafdataDoseringAtom = atom<Grafdata[]>((get) => {
    const grafdata = get(grafdataAtom);
    const doseringGrafdata = grafdata.filter((g) =>
        g.data.some((prod) => prod.dosering !== undefined && prod.dosering !== 0),
    );
    return doseringGrafdata ?? [];
});

export const reflinjeIKartAtom = atom<number | undefined>(undefined);
